import { useState, useEffect } from "react";
import { Table, InternalLink } from "@ess-ics/ce-ui-common";
import { JobStatusColumn } from "./JobStatusColumn";
import { JobDetailsColumn } from "./JobDetailsColumn";
import { UserAvatar } from "../../common/User/UserAvatar";

const defaultColumns = [
  {
    field: "status",
    headerName: "Status"
  },
  {
    field: "jobId",
    headerName: "Id"
  },
  {
    field: "job",
    headerName: "Details"
  },
  {
    field: "user",
    headerName: "User",
    align: "center",
    headerAlign: "center"
  }
];

const shapeColumns = (customColumns) => {
  return customColumns.map((column) => {
    const mappedCol = defaultColumns.find((col) => col.field === column.field);
    return mappedCol ? { ...mappedCol, ...column } : null;
  });
};

const createTableRow = (job, colorStyle) => ({
  id: job.id,
  status: <JobStatusColumn {...{ job }} />,
  jobId: (
    <InternalLink
      to={`/jobs/${job?.id}`}
      label={`Job Details, ID ${job.id}`}
    >
      {`#${job.id}`}
    </InternalLink>
  ),
  job: <JobDetailsColumn {...{ job, colorStyle }} />,
  user: <UserAvatar username={job.createdBy} />
});

export const JobTable = ({
  jobs,
  customColumns,
  pagination,
  onPage,
  loading
}) => {
  const [columns, setColumns] = useState(null);

  useEffect(() => {
    if (customColumns) {
      setColumns(shapeColumns(customColumns));
    } else {
      setColumns(defaultColumns);
    }
  }, [customColumns, setColumns]);

  return (
    <>
      {columns ? (
        <Table
          columns={columns}
          rows={columns && jobs?.map((job) => createTableRow(job))}
          pagination={pagination}
          onPage={onPage}
          loading={loading}
          rowHeight={90}
        />
      ) : null}
    </>
  );
};
